==> reflext.api-1.0.0-beta2-sources.jar: org/reflext/api/ClassTypeInfo.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.reflext.api;

import java.util.List;
import java.lang.annotation.Annotation;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public interface ClassTypeInfo extends TypeInfo, GenericDeclarationInfo {

  String getName();

  String getSimpleName();

  String getPackageName();

  ClassKind getKind();

  Iterable<TypeInfo> getInterfaces();

  TypeInfo getSuperType();

  TypeInfo resolve(TypeInfo type);

  List<MethodInfo> getDeclaredMethods();

  MethodInfo getDeclaredMethod(MethodSignature methodSignature);

  <A extends Annotation> A getDeclaredAnnotation(Class<A> annotationClass);

  boolean isAssignableFrom(ClassTypeInfo that);
}

==> reflext.api-1.1.0-beta2-sources.jar: org/reflext/api/ClassTypeInfo.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.reflext.api;

import org.reflext.api.annotation.Annotated;

import java.util.List;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public interface ClassTypeInfo extends TypeInfo, GenericDeclarationInfo, Annotated {

  String getName();

  String getSimpleName();

  String getPackageName();

  ClassKind getKind();

  Iterable<TypeInfo> getInterfaces();

  TypeInfo getSuperType();

  ClassTypeInfo getSuperClass();

  TypeInfo resolve(TypeInfo type);

  List<MethodInfo> getDeclaredMethods();

  MethodInfo getDeclaredMethod(MethodSignature methodSignature);

  boolean isAssignableFrom(ClassTypeInfo that);
}
